# Import Readwise Highlights into SQLite

Self-explanatory. Nice and simple importer for datasette.

```shell
pip install readwise-to-datasette
readwise-to-datasette
```

Or, from source:

```python
poetry install
poetry run readwise-to-datasette
```